/*
 * Copyright (C) 2023, KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: hxf <hewenfei@kylinos.cn>
 */

#include "ernie-bot.h"
#include "message-model.h"
#include "session-manager.h"

#include <QCoreApplication>
#include <QTranslator>
#include <QFile>

class ErnieBotPrivate
{
public:
    MessageModel *model {nullptr};
    SessionManager *sessionManager {nullptr};
};

ErnieBot::ErnieBot(QObject *parent) : MenuExtensionIFace(parent), d(new ErnieBotPrivate)
{
    QString translationFile("/usr/share/ukui-menu/extensions/translations/ernie-bot_" + QLocale::system().name() + ".qm");
    if (QFile::exists(translationFile)) {
        auto translator = new QTranslator(this);
        translator->load(translationFile);
        QCoreApplication::installTranslator(translator);
    }

    qRegisterMetaType<MessageModel*>("MessageModel*");

    d->sessionManager = new SessionManager(this);
    d->model = new MessageModel(this);

    connect(d->sessionManager, &SessionManager::sessionAdded, this, [this] (int sessionId) {
        d->model->setSession(d->sessionManager->getSession(sessionId));
    });

    connect(d->sessionManager, &SessionManager::sessionRemoved, this, [this] (int sessionId) {
        d->model->removeSession(sessionId);
    });
}

int ErnieBot::index()
{
    return 100;
}

QString ErnieBot::name()
{
    return tr("AI Assistant");
}

QUrl ErnieBot::url()
{
    return QUrl("qrc:///ernie-bot/content/ui/Main.qml");
}

QVariantMap ErnieBot::data()
{
    QVariantMap data;
    data.insert("messageModel", QVariant::fromValue(d->model));
    data.insert("sessionManager", QVariant::fromValue(d->sessionManager));
    return data;
}

void ErnieBot::receive(QVariantMap data)
{
    d->model->talk(data.value("message").toString());
}

QVariantList ErnieBot::options()
{
    QVariantList list;
    list << HideBottomBar << HideFullScreenButton;
    return list;
}
